# AnnotateOnlinePy
AnnotateOnline is a CLI for annotate.online.


## Installation
Prerequisites:
- Python 3.x
- pip

### Upload Images
1.	Install Python 3 on your machine.
2.	Install a virtual environment and pip.
3.	Activate the environment, and then install the annotateonline cli using pip:
``` pip install annotateonline ```
4.  Login to annotate.online.
5.  Go to "Projects" sections and select a project.
6.  Select the "Upload Images" button on the upper right corner and then select "Cli Uplaod" tab.
7.  Copy the command then replace the parameter ```<images_directory_path>``` with the images path on your machine.

